@@ -6,9 +6,9 @@ __doc__ = \
     """
 __author__ = "Matteo Ferla. [Github](https://github.com/matteoferla)"
 __email__ = "matteo.ferla@gmail.com"
-__date__ = "2020 A.D."
+__date__ = "2022 A.D."
 __license__ = "MIT"
-__version__ = "0.5"
+__version__ = "0.7"
 __citation__ = ""
 
 ########################################################################################################################
@@ -26,8 +26,13 @@ try:
 except ZeroDivisionError as err:
     warn(f'Victor (pipeline) unavailable —{err}.', category=ImportWarning)
 
+try:
+    from .multivictor import MultiVictorPlacement
+except ZeroDivisionError as err:
+    warn(f'Victor (pipeline) unavailable —{err}.', category=ImportWarning)
+
 from .monster import Monster
 from molecular_rectifier import Rectifier
-from .m_rmsd import mRSMD
+from .m_rmsd import mRMSD
 from .mpro import MProVictor
 from .mpro import data as mpro_data
